@@ -82,13 +82,13 @@ class BlockTimestampGraph(object):
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
-       return Point(2182936, 1596642898) #TODO: query status to get latest
+       return Point(2184972, 1596678993) #TODO: query status to get latest
         # return Point(2182936, 1596671999) #TODO: query status to get latest
 
     def get_point(self, x):
 #        return block_to_point(self._theta_provider.eth.getBlock(x))
         response = self._theta_provider.make_request(
-            json.dumps(generate_get_blocks_by_range_json_rpc(x, x + 1, False))
+            json.dumps(generate_get_blocks_by_range_json_rpc(x, x, False))
             )
         results = rpc_response_to_result(response)
         blocks = [self.block_mapper.json_dict_to_block(result) for result in results]
